@@ -29,34 +29,35 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CFLAGS_NODIST': '-ggdb -O2 -pipe -Wall -Werror=format-security '
                             '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
                             '--param=ssp-buffer-size=4 '
-                            '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.i686/build=/usr/src/debug/python39-3.9.9-3 '
-                            '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-3 '
+                            '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.10-1.i686/build=/usr/src/debug/python39-3.9.10-1 '
+                            '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10=/usr/src/debug/python39-3.9.10-1 '
                             '-DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ -std=c99 '
                             '-Wextra -Wno-unused-result -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
+                            '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '',
  'CONFIGURE_LDFLAGS': '',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--srcdir=/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9' "
+ 'CONFIG_ARGS': "'--srcdir=/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10' "
                 "'--prefix=/usr' '--exec-prefix=/usr' '--localstatedir=/var' "
-                "'--sysconfdir=/etc' '--docdir=/usr/share/doc/python39' "
-                "'--htmldir=/usr/share/doc/python39/html' '-C' "
-                "'--enable-shared' '--enable-ipv6' '--with-libc=' "
-                "'--with-libm=' '--with-system-expat' '--with-system-ffi' "
+                "'--sysconfdir=/etc' '--infodir=/usr/share/info' "
+                "'--mandir=/usr/share/man' '-C' '--enable-shared' "
+                "'--enable-ipv6' '--with-libc=' '--with-libm=' "
+                "'--with-system-expat' '--with-system-ffi' "
                 "'--without-ensurepip' "
                 "'ac_cv_func_bind_textdomain_codeset=yes' 'CC=gcc' 'CFLAGS=' "
                 "'LDFLAGS=' 'LIBS=' 'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/pub/devel/python/python39/python39-3.9.9-3.i686/build/coverage.info',
- 'COVERAGE_REPORT': '/pub/devel/python/python39/python39-3.9.9-3.i686/build/lcov-report',
+ 'COVERAGE_INFO': '/pub/devel/python/python39/python39-3.9.10-1.i686/build/coverage.info',
+ 'COVERAGE_REPORT': '/pub/devel/python/python39/python39-3.9.10-1.i686/build/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9/Include',
+             '-I/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10/Include',
  'CXX': 'g++',
  'DESTDIRS': '/usr /usr/lib /usr/lib/python3.9 /usr/lib/python3.9/lib-dynload',
  'DESTLIB': '/usr/lib/python3.9',
@@ -304,7 +305,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
  'HAVE_MEMFD_CREATE': 0,
- 'HAVE_MEMORY_H': 1,
+ 'HAVE_MEMORY_H': 0,
  'HAVE_MEMRCHR': 1,
  'HAVE_MKDIRAT': 1,
  'HAVE_MKFIFO': 1,
@@ -571,8 +572,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
- 'MAJOR_IN_SYSMACROS': 0,
- 'MAKESETUP': '/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9/Modules/makesetup',
+ 'MAJOR_IN_SYSMACROS': 1,
+ 'MAKESETUP': '/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
@@ -642,65 +643,66 @@ build_time_vars = {'ABIFLAGS': '',
                              '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                              '-fstack-protector-strong '
                              '--param=ssp-buffer-size=4 '
-                             '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.i686/build=/usr/src/debug/python39-3.9.9-3 '
-                             '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-3 '
+                             '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.10-1.i686/build=/usr/src/debug/python39-3.9.10-1 '
+                             '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10=/usr/src/debug/python39-3.9.10-1 '
                              '-DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ '
                              '-std=c99 -Wextra -Wno-unused-result '
                              '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
+                             '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden -ggdb -O2 -pipe -Wall '
                              '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                              '-fstack-protector-strong '
                              '--param=ssp-buffer-size=4 '
-                             '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.i686/build=/usr/src/debug/python39-3.9.9-3 '
-                             '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-3 '
+                             '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.10-1.i686/build=/usr/src/debug/python39-3.9.10-1 '
+                             '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10=/usr/src/debug/python39-3.9.10-1 '
                              '-DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ '
-                             '-I/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9/Include/internal '
+                             '-I/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10/Include/internal '
                              '-IObjects -IInclude -IPython -I. '
-                             '-I/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9/Include '
+                             '-I/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10/Include '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall',
  'PY_CFLAGS_NODIST': '-ggdb -O2 -pipe -Wall -Werror=format-security '
                      '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
                      '--param=ssp-buffer-size=4 '
-                     '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.i686/build=/usr/src/debug/python39-3.9.9-3 '
-                     '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-3 '
+                     '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.10-1.i686/build=/usr/src/debug/python39-3.9.10-1 '
+                     '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10=/usr/src/debug/python39-3.9.10-1 '
                      '-DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ -std=c99 '
                      '-Wextra -Wno-unused-result -Wno-unused-parameter '
-                     '-Wno-missing-field-initializers '
+                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden -ggdb -O2 -pipe -Wall '
                      '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                      '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                     '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.i686/build=/usr/src/debug/python39-3.9.9-3 '
-                     '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-3 '
+                     '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.10-1.i686/build=/usr/src/debug/python39-3.9.10-1 '
+                     '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10=/usr/src/debug/python39-3.9.10-1 '
                      '-DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ '
-                     '-I/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9/Include/internal',
+                     '-I/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
                    '-Wall -ggdb -O2 -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
                    '--param=ssp-buffer-size=4 '
-                   '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.i686/build=/usr/src/debug/python39-3.9.9-3 '
-                   '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-3 '
+                   '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.10-1.i686/build=/usr/src/debug/python39-3.9.10-1 '
+                   '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10=/usr/src/debug/python39-3.9.10-1 '
                    '-DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ -std=c99 -Wextra '
                    '-Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers '
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden '
                    '-ggdb -O2 -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
                    '--param=ssp-buffer-size=4 '
-                   '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.i686/build=/usr/src/debug/python39-3.9.9-3 '
-                   '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-3 '
+                   '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.10-1.i686/build=/usr/src/debug/python39-3.9.10-1 '
+                   '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10=/usr/src/debug/python39-3.9.10-1 '
                    '-DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ '
-                   '-I/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9/Include/internal '
+                   '-I/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
-                   '-I/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9/Include '
+                   '-I/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10/Include '
                    '-DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9/Include',
+                '-I/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10/Include',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '',
  'PY_LDFLAGS_NODIST': '',
@@ -710,21 +712,21 @@ build_time_vars = {'ABIFLAGS': '',
                         '-O3 -Wall -ggdb -O2 -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                        '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.i686/build=/usr/src/debug/python39-3.9.9-3 '
-                        '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-3 '
+                        '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.10-1.i686/build=/usr/src/debug/python39-3.9.10-1 '
+                        '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10=/usr/src/debug/python39-3.9.10-1 '
                         '-DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ -std=c99 '
                         '-Wextra -Wno-unused-result -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers '
+                        '-Wno-missing-field-initializers -Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden -ggdb -O2 -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                        '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.i686/build=/usr/src/debug/python39-3.9.9-3 '
-                        '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-3 '
+                        '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.10-1.i686/build=/usr/src/debug/python39-3.9.10-1 '
+                        '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10=/usr/src/debug/python39-3.9.10-1 '
                         '-DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ '
-                        '-I/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9/Include/internal '
+                        '-I/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10/Include/internal '
                         '-IObjects -IInclude -IPython -I. '
-                        '-I/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9/Include',
+                        '-I/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10/Include',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -762,7 +764,7 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-39-i386-cygwin',
  'SRCDIRS': 'Parser Parser/pegen Objects Python Modules Modules/_io Programs',
- 'SRC_GDB_HOOKS': '/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -777,7 +779,7 @@ build_time_vars = {'ABIFLAGS': '',
  'TESTPYTHON': './python.exe',
  'TESTPYTHONOPTS': '',
  'TESTRUNNER': './python.exe '
-               '/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9/Tools/scripts/run_tests.py',
+               '/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10/Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
@@ -786,10 +788,10 @@ build_time_vars = {'ABIFLAGS': '',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'UPDATE_FILE': 'python3.9 '
-                '/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9/Tools/scripts/update_file.py',
+                '/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10/Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
  'VERSION': '3.9',
- 'VPATH': '/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9',
+ 'VPATH': '/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10',
  'WINDOW_HAS_FLAGS': 0,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
@@ -801,9 +803,9 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 1,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/pub/devel/python/python39/python39-3.9.9-3.i686/build',
- 'abs_srcdir': '/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9',
+ 'abs_builddir': '/pub/devel/python/python39/python39-3.9.10-1.i686/build',
+ 'abs_srcdir': '/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
- 'srcdir': '/pub/devel/python/python39/python39-3.9.9-3.i686/src/Python-3.9.9'}
+ 'srcdir': '/pub/devel/python/python39/python39-3.9.10-1.i686/src/Python-3.9.10'}
